==> haskell-easy-file-0.2.5-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-easy-file.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 easy-file
version:              0.2.5
visibility:           public
id:                   easy-file-0.2.5-C9RmHuL2t5675vmDcIqIf5
key:                  easy-file-0.2.5-C9RmHuL2t5675vmDcIqIf5
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://github.com/kazu-yamamoto/easy-file
synopsis:             Cross-platform File handling
description:          Cross-platform File handling for Unix\/Mac\/Windows
category:             System
abi:                  cffb637215cb166520ae11545ef9708c
exposed:              True
exposed-modules:      System.EasyFile
hidden-modules:
    System.EasyFile.FilePath System.EasyFile.Directory
    System.EasyFile.Missing

import-dirs:          /usr/lib/ghc-9.0.2/site-local/easy-file-0.2.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/easy-file-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-easy-file
hs-libraries:         HSeasy-file-0.2.5-C9RmHuL2t5675vmDcIqIf5
depends:
    base-4.15.1.0 directory-1.3.6.2 filepath-1.4.2.1 time-1.9.3
    unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-easy-file/html/easy-file.haddock
haddock-html:         /usr/share/doc/haskell-easy-file/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-easy-file-0.2.5-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-easy-file.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 easy-file
version:              0.2.5
visibility:           public
id:                   easy-file-0.2.5-KYTWMSg9vFXBCje3B3lA4v
key:                  easy-file-0.2.5-KYTWMSg9vFXBCje3B3lA4v
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://github.com/kazu-yamamoto/easy-file
synopsis:             Cross-platform File handling
description:          Cross-platform File handling for Unix\/Mac\/Windows
category:             System
abi:                  74b60f45e3d9e6bf17a190e2e336e7c6
exposed:              True
exposed-modules:      System.EasyFile
hidden-modules:
    System.EasyFile.FilePath System.EasyFile.Directory
    System.EasyFile.Missing

import-dirs:          /usr/lib/ghc-9.0.2/site-local/easy-file-0.2.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/easy-file-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-easy-file
hs-libraries:         HSeasy-file-0.2.5-KYTWMSg9vFXBCje3B3lA4v
depends:
    base-4.15.1.0 directory-1.3.6.2 filepath-1.4.2.1 time-1.9.3
    unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-easy-file/html/easy-file.haddock
haddock-html:         /usr/share/doc/haskell-easy-file/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
